@@ -10,7 +10,7 @@ use Term::ANSIColor ();
 use Path::Class qw( file dir );
 
 # ABSTRACT: Dist::Zilla plugin bundle used by Plicease
-our $VERSION = '1.80'; # VERSION
+our $VERSION = '1.81'; # VERSION
 
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
@@ -221,10 +221,12 @@ sub configure
   if(-e ".travis.yml")
   {
     my $travis = YAML::LoadFile(".travis.yml");
+    
     if(exists $travis->{perl} && grep /^5\.19$/, @{ $travis->{perl} })
     {
       die "travis is trying to test Perl 5.19";
     }
+    
     unless(exists $travis->{perl} && grep /^5\.20$/, @{ $travis->{perl} })
     {
       print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
@@ -232,6 +234,14 @@ sub configure
       print STDERR Term::ANSIColor::color('reset') if -t STDERR;
       print STDERR "\n";
     }
+    
+    unless(exists $travis->{sudo})
+    {
+      print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
+      print STDERR "You have not specified a value for sudo in travis (suggest setting to false for faster travis build)";
+      print STDERR Term::ANSIColor::color('reset') if -t STDERR;
+      print STDERR "\n";
+    }
   }
 }
 
@@ -251,7 +261,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 1.80
+version 1.81
 
 =head1 SYNOPSIS
 
